package userProduct

import (
	"context"
	"errors"
	"tianyuan-api/apps/sentinel/client/userproduct"

	"tianyuan-api/apps/gateway/internal/svc"
	"tianyuan-api/apps/gateway/internal/types"

	"github.com/zeromicro/go-zero/core/logx"
)

type GetUserProductListLogic struct {
	logx.Logger
	ctx    context.Context
	svcCtx *svc.ServiceContext
}

func NewGetUserProductListLogic(ctx context.Context, svcCtx *svc.ServiceContext) *GetUserProductListLogic {
	return &GetUserProductListLogic{
		Logger: logx.WithContext(ctx),
		ctx:    ctx,
		svcCtx: svcCtx,
	}
}

func (l *GetUserProductListLogic) GetUserProductList(req *types.GetUserProductListReq) (resp *types.GetUserProductListResp, err error) {
	userId, ok := l.ctx.Value("userId").(int64)
	if !ok {
		return nil, errors.New("无法获取 userId")
	}
	userProductPageListResp, err := l.svcCtx.UserProductRpc.GetUserProductPageList(l.ctx, &userproduct.UserProuctPageListRequest{
		UserId:   userId,
		Page:     req.Page,
		PageSize: req.PageSize,
	})
	if err != nil {
		return nil, err
	}
	var list []types.UserProductItem
	for _, up := range userProductPageListResp.UserProducts {
		list = append(list, types.UserProductItem{
			Id:                 up.Id,
			ProductId:          up.ProductId,
			ProductName:        up.ProductName,
			ProductPrice:       up.ProductPrice,
			ProductGroup:       up.ProductGroup,
			ProductCode:        up.ProductCode,
			ProductDescription: up.ProductDescription,
			CreatedAt:          up.CreatedAt,
			UpdatedAt:          up.UpdatedAt,
		})
	}
	resp = &types.GetUserProductListResp{
		Total: userProductPageListResp.Total,
		List:  list,
	}
	return resp, nil
}
