package product

import (
	"context"
	"tianyuan-api/apps/sentinel/client/product"

	"tianyuan-api/apps/index/internal/svc"
	"tianyuan-api/apps/index/internal/types"

	"github.com/zeromicro/go-zero/core/logx"
)

type GetProductListLogic struct {
	logx.Logger
	ctx    context.Context
	svcCtx *svc.ServiceContext
}

func NewGetProductListLogic(ctx context.Context, svcCtx *svc.ServiceContext) *GetProductListLogic {
	return &GetProductListLogic{
		Logger: logx.WithContext(ctx),
		ctx:    ctx,
		svcCtx: svcCtx,
	}
}

func (l *GetProductListLogic) GetProductList(req *types.GetProductListReq) (resp *types.GetProductListResp, err error) {
	productList, err := l.svcCtx.ProductRpc.GetProductPageList(l.ctx, &product.PageListRequest{Page: req.Page, PageSize: req.PageSize})
	if err != nil {
		return nil, err
	}
	var list []types.ProductItem

	for _, p := range productList.Products {
		list = append(list, types.ProductItem{
			ProductId:          p.Id,
			ProductName:        p.ProductName,
			ProductCode:        p.ProductCode,
			ProductDescription: p.ProductDescription,
			ProductPrice:       p.ProductPrice,
			ProductGroup:       p.ProductGroup,
			CreatedAt:          p.CreatedAt,
			UpdatedAt:          p.UpdatedAt,
		})
	}
	resp = &types.GetProductListResp{
		Total: productList.Total,
		List:  list,
	}
	return resp, nil
}
