package apirequest

import (
	"context"
	"encoding/json"
	"tianyuan-api/apps/mqs/internal/svc"
	"tianyuan-api/apps/user/user"
	"tianyuan-api/pkg/models"
	"time"
)

type Log struct {
	ctx    context.Context
	svcCtx *svc.ServiceContext
}

func NewLog(ctx context.Context, svcCtx *svc.ServiceContext) *Log {
	return &Log{
		ctx:    ctx,
		svcCtx: svcCtx,
	}
}

func (l *Log) Consume(ctx context.Context, key, val string) error {
	var apiRequestMessage models.ApiRequestMessage
	err := json.Unmarshal([]byte(val), &apiRequestMessage)
	if err != nil {
		return err
	}
	_, err = l.svcCtx.ApiRequestRpc.AddApiRequest(ctx, &user.AddApiRequestRequest{
		TransactionId: apiRequestMessage.TransactionID,
		UserId:        apiRequestMessage.UserId,
		ProductCode:   apiRequestMessage.ProductCode,
		Status:        apiRequestMessage.Status,
		Charges:       apiRequestMessage.Charges,
		Remark:        apiRequestMessage.Remark,
		Timestamp:     apiRequestMessage.Timestamp.Format(time.RFC3339Nano),
	})
	if err != nil {
		return err
	}
	return nil
}
