package userproductlogic

import (
	"context"
	"tianyuan-api/apps/sentinel/client/product"
	"tianyuan-api/pkg/sqlutil"

	"tianyuan-api/apps/sentinel/internal/svc"
	"tianyuan-api/apps/sentinel/sentinel"

	"github.com/zeromicro/go-zero/core/logx"
)

type GetUserProductPageListLogic struct {
	ctx    context.Context
	svcCtx *svc.ServiceContext
	logx.Logger
}

func NewGetUserProductPageListLogic(ctx context.Context, svcCtx *svc.ServiceContext) *GetUserProductPageListLogic {
	return &GetUserProductPageListLogic{
		ctx:    ctx,
		svcCtx: svcCtx,
		Logger: logx.WithContext(ctx),
	}
}

func (l *GetUserProductPageListLogic) GetUserProductPageList(in *sentinel.UserProuctPageListRequest) (*sentinel.UserProductPageListResponse, error) {
	list, total, err := l.svcCtx.UserProductsModel.FindUserProductsList(l.ctx, in.UserId, in.Page, in.PageSize)
	if err != nil {
		return nil, err
	}

	var userProducts []*product.UserProductItem
	for _, up := range list {
		userProducts = append(userProducts, &product.UserProductItem{
			Id:                 up.Id,
			ProductId:          up.ProductId,
			ProductName:        up.ProductName,
			ProductPrice:       up.ProductPrice,
			ProductGroup:       up.ProductGroup,
			ProductDescription: sqlutil.NullStringToString(up.ProductDescription),
			ProductCode:        up.ProductCode,
			CreatedAt:          up.CreatedAt.Format("2006-01-02 15:04:05"),
			UpdatedAt:          up.UpdatedAt.Format("2006-01-02 15:04:05"),
		})
	}
	return &sentinel.UserProductPageListResponse{
		Total:        total,
		UserProducts: userProducts,
	}, nil
}
