package main

import (
	"flag"
	"fmt"
	"os"

	"tianyuan-api/apps/sentinel/internal/config"
	productServer "tianyuan-api/apps/sentinel/internal/server/product"
	secretServer "tianyuan-api/apps/sentinel/internal/server/secret"
	topupServer "tianyuan-api/apps/sentinel/internal/server/topup"
	userproductServer "tianyuan-api/apps/sentinel/internal/server/userproduct"
	whitelistServer "tianyuan-api/apps/sentinel/internal/server/whitelist"
	"tianyuan-api/apps/sentinel/internal/svc"
	"tianyuan-api/apps/sentinel/sentinel"

	"github.com/zeromicro/go-zero/core/conf"
	"github.com/zeromicro/go-zero/core/service"
	"github.com/zeromicro/go-zero/zrpc"
	"google.golang.org/grpc"
	"google.golang.org/grpc/reflection"
)

func main() {
	env := os.Getenv("ENV")
	if env == "" {
		env = "production"
	}

	// 根据 ENV 加载不同的配置文件
	var defaultConfigFile string
	if env == "development" {
		defaultConfigFile = "etc/sentinel.dev.yaml" // 开发环境配置
	} else {
		defaultConfigFile = "etc/sentinel.yaml" // 生产环境配置
	}

	// 允许通过命令行参数覆盖配置文件路径
	configFile := flag.String("f", defaultConfigFile, "the config file")
	flag.Parse()

	var c config.Config
	conf.MustLoad(*configFile, &c)
	ctx := svc.NewServiceContext(c)

	s := zrpc.MustNewServer(c.RpcServerConf, func(grpcServer *grpc.Server) {
		sentinel.RegisterWhitelistServer(grpcServer, whitelistServer.NewWhitelistServer(ctx))
		sentinel.RegisterSecretServer(grpcServer, secretServer.NewSecretServer(ctx))
		sentinel.RegisterProductServer(grpcServer, productServer.NewProductServer(ctx))
		sentinel.RegisterUserProductServer(grpcServer, userproductServer.NewUserProductServer(ctx))
		sentinel.RegisterTopUpServer(grpcServer, topupServer.NewTopUpServer(ctx))

		if c.Mode == service.DevMode || c.Mode == service.TestMode {
			reflection.Register(grpcServer)
		}
	})
	defer s.Stop()

	fmt.Printf("Starting rpc server at %s...\n", c.ListenOn)
	s.Start()
}
