package enterpriselogic

import (
	"context"

	"tianyuan-api/apps/user/internal/svc"
	"tianyuan-api/apps/user/user"

	"github.com/zeromicro/go-zero/core/logx"
)

type GetPendingEnterpriseLogic struct {
	ctx    context.Context
	svcCtx *svc.ServiceContext
	logx.Logger
}

func NewGetPendingEnterpriseLogic(ctx context.Context, svcCtx *svc.ServiceContext) *GetPendingEnterpriseLogic {
	return &GetPendingEnterpriseLogic{
		ctx:    ctx,
		svcCtx: svcCtx,
		Logger: logx.WithContext(ctx),
	}
}

// 获取待审核企业列表
func (l *GetPendingEnterpriseLogic) GetPendingEnterprise(in *user.GetPendingEnterpriseReq) (*user.GetPendingEnterpriseResp, error) {
	// 调用 Model 层获取待审核企业列表
	enterprises, total, err := l.svcCtx.EnterpriseAuthModel.FindPendingList(l.ctx, in.Page, in.PageSize)
	if err != nil {
		return nil, err
	}

	// 构造返回的企业列表
	var list []*user.EnterpriseItem
	for _, e := range enterprises {
		list = append(list, &user.EnterpriseItem{
			Id:                e.Id,
			EnterpriseName:    e.EnterpriseName,
			CreditCode:        e.CreditCode,
			LegalPerson:       e.LegalPerson,
			EnterpriseContact: e.EnterpriseContact,
			AuthStatus:        e.AuthStatus,
			BusinessLicense:   e.BusinessLicense,
			CreatedAt:         e.CreatedAt.Format("2006-01-02 15:04:05"),
			UpdatedAt:         e.UpdatedAt.Format("2006-01-02 15:04:05"),
		})
	}

	return &user.GetPendingEnterpriseResp{
		Total: total,
		List:  list,
	}, nil
}
