package userlogic

import (
	"context"
	"database/sql"
	"errors"
	"tianyuan-api/apps/user/internal/svc"
	"tianyuan-api/apps/user/user"

	"github.com/zeromicro/go-zero/core/logx"
)

type UserInfoLogic struct {
	ctx    context.Context
	svcCtx *svc.ServiceContext
	logx.Logger
}

func NewUserInfoLogic(ctx context.Context, svcCtx *svc.ServiceContext) *UserInfoLogic {
	return &UserInfoLogic{
		ctx:    ctx,
		svcCtx: svcCtx,
		Logger: logx.WithContext(ctx),
	}
}

// 获取用户信息
func (l *UserInfoLogic) UserInfo(in *user.UserInfoReq) (*user.UserInfoResp, error) {
	// 查询用户信息
	users, err := l.svcCtx.UserModel.FindOne(l.ctx, in.UserId)
	if err != nil {
		return nil, errors.New("用户不存在")
	}

	if users.AuthStatus == "approved" {
		enterprise, findEntErr := l.svcCtx.EnterpriseModel.FindOneByUserId(l.ctx, users.Id)
		if findEntErr != nil && !errors.Is(findEntErr, sql.ErrNoRows) {
			return nil, errors.New("failed to query enterprise auth info")
		}
		wallet, findWalletErr := l.svcCtx.WalletsModel.FindOneByUserId(l.ctx, in.UserId)
		if findWalletErr != nil {
			return nil, findWalletErr
		}
		// 正常返回用户和企业信息
		return &user.UserInfoResp{
			Username:             users.Username,
			Phone:                users.Phone,
			EnterpriseAuthStatus: users.AuthStatus,
			EnterpriseName:       enterprise.EnterpriseName,
			CreditCode:           enterprise.CreditCode,
			LegalPerson:          enterprise.LegalPerson,
			Balance:              wallet.Balance,
		}, nil
	}
	return &user.UserInfoResp{
		Username:             users.Username,
		Phone:                users.Phone,
		EnterpriseAuthStatus: users.AuthStatus,
	}, nil

}
